#
# Copyright (C) 2015  Ilya Markov
#
# Full copyright notice can be found in LICENSE.
#
import sys
import russir2016_utils

__author__ = 'Ilya Markov'


if __name__ == "__main__":
    if len(sys.argv) < 4:
        print "USAGE: %s <dataset> <sessions_max> <click_model>" % sys.argv[0]
        print "\tdataset - the path to the dataset from Yandex Relevance Prediction Challenge"
        print "\tsessions_max - the maximum number of one-query search sessions to consider"
        print "\tclick_model - the name of a click model to use."
        print ""
        sys.exit(1)

    print "==============================="
    print "The script calculates full and conditional click probabilities according to %s." % sys.argv[3]
    print "==============================="

    search_sessions_path = sys.argv[1]
    search_sessions_num = int(sys.argv[2])
    train_sessions, train_queries, test_sessions, test_queries = russir2016_utils.get_train_test(
        search_sessions_path, search_sessions_num
    )

    click_model_name = sys.argv[3]
    click_model = russir2016_utils.get_click_model(click_model_name)

    print "-------------------------------"
    print "Training on %d search sessions (%d unique queries)." % (len(train_sessions), len(train_queries))
    print "-------------------------------"

    click_model.train(train_sessions)

    for i in range(10):
        click_probs_full = click_model.get_full_click_probs(test_sessions[i])
        click_probs_cond = click_model.get_conditional_click_probs(test_sessions[i])

        print 'Search session %d' % (i + 1)
        print '%r - actual clicks' % test_sessions[i].get_clicks()
        print '[%s] - full click probabilities according to %s' % \
              (', '.join(['%.4f' % click_prob for click_prob in click_probs_full]), click_model_name)
        print '[%s] - conditional click probabilities according to %s' % \
              (', '.join(['%.4f' % click_prob for click_prob in click_probs_cond]), click_model_name)
        print ''
